==> ultramarked-0.7.0.tgz: package/src/core.js <==
'use strict';

var marked = require('marked'),
    hljs = require('highlight.js'),
    exports = module.exports = ultramarked,
    alises = exports.aliases = {
        'js': 'javascript',
        'md': 'markdown',
        'html': 'xml', // next best thing
        'jade': 'css' // next best thing
    };

hljs.configure({ classPrefix: 'hljs-' });

function merge(obj) {
    var i = 1, target, key;

    for(; i < arguments.length; i++){
        target = arguments[i];

        for(key in target){
            if(Object.prototype.hasOwnProperty.call(target, key)){
                obj[key] = target[key];
            }
        }
    }
    return obj;
}

function getHighlightingRenderer (prev) {
    var renderer = prev || new marked.Renderer();
    var baseCodeRenderer = renderer.code;
    var baseCodeSpanRenderer = renderer.codespan;

    renderer.code = function () {
        var result = baseCodeRenderer.apply(this, arguments);
        var classed = result.replace(/^<pre><code>/i, '<pre class="hljs-pre"><code class="hljs">');
        return classed;
    };
    renderer.codespan = function () {
        var result = baseCodeSpanRenderer.apply(this, arguments);
        var classed = result.replace(/^<code>/i, '<code class="hljs">');
        return classed;
    };
    return renderer;
}

function ultramarked(src, opt) {
    var options = merge({}, marked.defaults, opt),
        aliases = options.aliases || exports.aliases,
        no = 'no-highlight';

    if (options.terminal){
        delete options.ultralight;
        delete options.ultrasanitize;
    }
    if (options.ultralight){
        options.langPrefix = 'ultralight-lang-'; // placeholder
        options.highlight = function (code, lang) {
            if (!lang) {
                return code;
            }
            var lower = lang.toLowerCase();
            try{
                return hljs.highlight(aliases[lower] || lower, code).value;
            } catch (ex) {} // marked will know what to do.
        };
        options.renderer = getHighlightingRenderer(options.renderer);
    }

    var tokens = marked.lexer(src, options),
        result = marked.parser(tokens, options);

    if (options.ultralight) { // fix the language class using common aliases
        result = result.replace(/"ultralight-lang-([\w-]+)"/ig, function (match, lang) {
            var lower = lang.toLowerCase(),
                result = aliases[lower] || lower || no;

            return '"hljs ' + result + '"';
        });
        result = result.replace(/^<pre>/, '<pre class="hljs-pre">');
    }

    if(options.ultrasanitize){
        result = require('./sanitizer.js')(result);
    }else if(options.ultrasanitize_pagedown){
        result = require('./sanitizer-pagedown.js')(result);
    }

    return result;
}

ultramarked.setOptions = marked.setOptions;

==> ultramarked-0.8.0.tgz: package/src/core.js <==
'use strict';

var marked = require('marked'),
    hljs = require('highlight.js'),
    exports = module.exports = ultramarked,
    alises = exports.aliases = {
        'js': 'javascript',
        'md': 'markdown',
        'html': 'xml', // next best thing
        'jade': 'css' // next best thing
    };

hljs.configure({ classPrefix: 'hljs-' });

function merge(obj) {
    var i = 1, target, key;

    for(; i < arguments.length; i++){
        target = arguments[i];

        for(key in target){
            if(Object.prototype.hasOwnProperty.call(target, key)){
                obj[key] = target[key];
            }
        }
    }
    return obj;
}

function getHighlightingRenderer (prev) {
    var renderer = prev || new marked.Renderer();
    var baseCodeRenderer = renderer.code;
    var baseCodeSpanRenderer = renderer.codespan;

    renderer.code = function () {
        var result = baseCodeRenderer.apply(this, arguments);
        var classed = result.replace(/^<pre><code>/i, '<pre class="hljs-pre"><code class="hljs">');
        return classed;
    };
    renderer.codespan = function () {
        var result = baseCodeSpanRenderer.apply(this, arguments);
        var classed = result.replace(/^<code>/i, '<code class="hljs">');
        return classed;
    };
    return renderer;
}

function ultramarked(src, opt) {
    var options = merge({}, marked.defaults, opt),
        aliases = options.aliases || exports.aliases,
        no = 'no-highlight';

    if (options.terminal){
        delete options.ultralight;
        delete options.ultrasanitize;
    }
    if (options.ultralight){
        options.langPrefix = 'ultralight-lang-'; // placeholder
        options.highlight = function (code, lang) {
            if (!lang) {
                return code;
            }
            var lower = lang.toLowerCase();
            try{
                return hljs.highlight(aliases[lower] || lower, code).value;
            } catch (ex) {} // marked will know what to do.
        };
        options.renderer = getHighlightingRenderer(options.renderer);
    }

    var tokens = marked.lexer(src, options),
        result = marked.parser(tokens, options);

    if (options.ultralight) { // fix the language class using common aliases
        result = result.replace(/"ultralight-lang-([\w-]+)"/ig, function (match, lang) {
            var lower = lang.toLowerCase(),
                result = aliases[lower] || lower || no;

            return '"hljs ' + result + '"';
        });
        result = result.replace(/^<pre>/, '<pre class="hljs-pre">');
    }

    if(options.ultrasanitize){
        result = require('./sanitizer.js')(result);
    }else if(options.sanitizer){
        result = options.sanitizer(result);
    }

    return result;
}

ultramarked.setOptions = marked.setOptions;
